aboutsummaryrefslogtreecommitdiffstats
path: root/railties/lib/rails_generator/generators
diff options
context:
space:
mode:
Diffstat (limited to 'railties/lib/rails_generator/generators')
-rw-r--r--railties/lib/rails_generator/generators/applications/app/app_generator.rb7
1 files changed, 4 insertions, 3 deletions
diff --git a/railties/lib/rails_generator/generators/applications/app/app_generator.rb b/railties/lib/rails_generator/generators/applications/app/app_generator.rb
index 79bb808d7b..65d6afd9ab 100644
--- a/railties/lib/rails_generator/generators/applications/app/app_generator.rb
+++ b/railties/lib/rails_generator/generators/applications/app/app_generator.rb
@@ -37,8 +37,9 @@ class AppGenerator < Rails::Generator::Base
:app_name => File.basename(File.expand_path(@destination_root)),
:socket => @socket
}
- m.template "configs/routes.rb", "config/routes.rb"
- m.template "configs/apache.conf", "public/.htaccess"
+ m.template "configs/routes.rb", "config/routes.rb"
+ m.template "configs/apache.conf", "public/.htaccess"
+ m.template "configs/lighttpd.conf", "config/lighttpd.conf"
# Environments
m.file "environments/boot.rb", "config/boot.rb"
@@ -48,7 +49,7 @@ class AppGenerator < Rails::Generator::Base
m.file "environments/test.rb", "config/environments/test.rb"
# Scripts
%w( breakpointer console destroy generate performance/benchmarker performance/profiler process/reaper process/spawner process/spinner runner server ).each do |file|
m.file "bin/#{file}", "script/#{file}", script_options
end
@@ -48,7 +49,7 @@ class AppGenerator < Rails::Generator::Base
m.file "environments/test.rb", "config/environments/test.rb"
# Scripts
- %w( breakpointer console destroy generate performance/benchmarker performance/profiler process/reaper process/spawner process/spinner runner server ).each do |file|
+ %w( breakpointer console destroy generate performance/benchmarker performance/profiler process/reaper process/spawner process/spinner runner server lighttpd ).each do |file|
m.file "bin/#{file}", "script/#{file}", script_options
end